---
name: Generic issue template
about: Should be used for all issues
title: ''
labels: ''
assignees: ''

---

Issue raised by: [developer/user/project requirement]

### What?
What is the issue

### Where?
Where is the issue likely to be (be as specific as possible)

### How?
How did the issue come about

### Reproducible?
[Yes/No]

### How to test the issue is resolved
A set of instructions / A script / Include test files if required
